Bounds

Enum Bounds 

pub enum Bounds {
    Min(f32),
    Max(f32),
    Both {
        min: f32,
        max: f32,
    },
}
The space limits of a Bounded length.

Variants



Min(f32)

The length must be at least a certain amount of pixels.



Max(f32)

The length must not exceed a certain amount of pixels.



Both

The length must be inside a range of pixels.

Fields

min: f32

The minimum boundary.

max: f32

The maximum boundary.

Implementations

Source

impl Bounds

pub fn min(self, min: f32) -> Self

Applies a new minimum boundary to the current Bounds.

pub fn max(self, max: f32) -> Self

Applies a new maximum boundary to the current Bounds.

pub fn constraint(self) -> Constraint

Returns a Constraint that represents the current Bounds.