pub enum Constraint {
Min(f32),
Max,
}Expand description
The limit of a Fluid length.
Variants
Min(f32)
Fill available space, but never shrinks below the given amount.
Max
Fill available space, but never beyond the size the element resolves to on its own; releasing any share it doesn’t use back to its siblings.