pub enum Bounds {
Min(f32),
Max(f32),
Both {
min: f32,
max: f32,
},
}Expand description
The space limits of a Bounded length.
Variants
Min(f32)
The length must be at least a certain amount of pixels.
Max(f32)
The length must not exceed a certain amount of pixels.
Both
The length must be inside a range of pixels.
Implementations
Sourceimpl Bounds
impl Bounds
Sourcepub fn constraint(self) -> Constraint
pub fn constraint(self) -> Constraint
Returns a Constraint that represents the current Bounds.